==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ScatterLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterLineSeriesDescription } from "./ScatterLineSeriesDescription";
/**
 * @hidden
 */
export let ScatterLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterLineSeriesDescriptionMetadata.a == null) {
                ScatterLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterLineSeriesDescriptionMetadata.c(ScatterLineSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(ScatterLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            ScatterBaseDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            ScatterLineSeriesDescriptionMetadata.b(a);
            a.ad("ScatterLineSeries", () => new ScatterLineSeriesDescription());
            a.ac("ScatterLineSeries", ScatterLineSeriesDescriptionMetadata.a);
        }
    }
    ScatterLineSeriesDescriptionMetadata.$t = markType(ScatterLineSeriesDescriptionMetadata, 'ScatterLineSeriesDescriptionMetadata');
    ScatterLineSeriesDescriptionMetadata.a = null;
    return ScatterLineSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ScatterLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterLineSeriesDescription } from "./ScatterLineSeriesDescription";
/**
 * @hidden
 */
export let ScatterLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterLineSeriesDescriptionMetadata.a == null) {
                ScatterLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterLineSeriesDescriptionMetadata.c(ScatterLineSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(ScatterLineSeriesDescriptionMetadata.a);
        }
        static c(a) {
            ScatterBaseDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            ScatterLineSeriesDescriptionMetadata.b(a);
            a.ae("ScatterLineSeries", () => new ScatterLineSeriesDescription());
            a.ad("ScatterLineSeries", ScatterLineSeriesDescriptionMetadata.a);
        }
    }
    ScatterLineSeriesDescriptionMetadata.$t = markType(ScatterLineSeriesDescriptionMetadata, 'ScatterLineSeriesDescriptionMetadata');
    ScatterLineSeriesDescriptionMetadata.a = null;
    return ScatterLineSeriesDescriptionMetadata;
})();
